from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class LeasePolicyResponse(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The allowRenewal property
    allow_renewal: Optional[bool] = None
    # The defaultTtlMinutes property
    default_ttl_minutes: Optional[int] = None
    # The maxTtlMinutes property
    max_ttl_minutes: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> LeasePolicyResponse:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: LeasePolicyResponse
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return LeasePolicyResponse()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "allowRenewal": lambda n : setattr(self, 'allow_renewal', n.get_bool_value()),
            "defaultTtlMinutes": lambda n : setattr(self, 'default_ttl_minutes', n.get_int_value()),
            "maxTtlMinutes": lambda n : setattr(self, 'max_ttl_minutes', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_bool_value("allowRenewal", self.allow_renewal)
        writer.write_int_value("defaultTtlMinutes", self.default_ttl_minutes)
        writer.write_int_value("maxTtlMinutes", self.max_ttl_minutes)
        writer.write_additional_data_value(self.additional_data)
    

